﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace SfGrid

{
    public class StocksViewModel : INotifyPropertyChanged
    {
        #region Members

        ObservableCollection<StockData> data;
        Random r = new Random(123345345);
        List<string> StockSymbols = new List<string>();
        string[] accounts = new string[]{
            "AmericanFunds",
            "ChildrenCollegeSavings",
            "DayTrading",
            "RetirementSavings",
            "MountainRanges",
            "FidelityFunds",
            "Mortages",
            "HousingLoans"
        };

        #endregion

        private ObservableCollection<int> comboSource;

        public ObservableCollection<int> ComboSource
        {
            get { return comboSource; }
            set { comboSource = value; }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }

        private int limit = 0;

        public int Limit
        {
            get { return limit; }
            set
            {
                limit = value;

                Stocks.Clear();

                AddRows(limit);

                OnPropertyChanged("Limit");
            }
        }

        #region Public Members

        /// <summary>
        /// Gets the stocks.
        /// </summary>
        /// <value>The stocks.</value>
        public ObservableCollection<StockData> Stocks
        {
            get
            {
                return data;
            }
            set
            {
                data = value;
                OnPropertyChanged("Stocks");
            }
        }

        #endregion

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="StocksViewModel"/> class.
        /// </summary>
        public StocksViewModel()
        {
            this.data = new ObservableCollection<StockData>();
            
            AddEmptyGroup();

            this.AddRows(50);
            
            this.ComboSource = new ObservableCollection<int>();
            for (int i = 0; i <= 10; i++)
            {
                this.ComboSource.Add(i);
            }
        }

        
        #endregion

        #region Helper Methods

        private void AddEmptyGroup()
        {
            var rec = new StockData();
            rec.Account = "**Empty Group**";
            rec.LastTrade = 0;
            rec.Open = 0;
            rec.Change = 0;

            rec.PreviousClose = 0;
            rec.Volume = 0;

            data.Add(rec);
        }

        /// <summary>
        /// Adds the rows.
        /// </summary>
        /// <param name="count">The count.</param>
        private void AddRows(int count)
        {
            for (int i = 0; i < count; ++i)
            {
                var newRec = new StockData();
                newRec.Account = ChangeAccount(i);
                newRec.Open = Math.Round(r.NextDouble() * 30, 2);
                newRec.LastTrade = Math.Round((1 + r.NextDouble() * 50));
                double d = r.NextDouble();
                if (d < .5)
                    newRec.Change = Math.Round(d, 2);
                else
                    newRec.Change = Math.Round(d, 2) * -1;

                newRec.PreviousClose = Math.Round(r.NextDouble() * 30, 2);
                newRec.Volume = r.Next();
                data.Add(newRec);
            }
        }

        /// Changes the account.
        /// </summary>
        /// <param name="index">The index.</param>
        /// <returns></returns>
        private String ChangeAccount(int index)
        {
            return accounts[index % accounts.Length];
        }

        #endregion
    }
}
